==> okta-sdk-api-20.0.1-sources.jar: com/okta/sdk/resource/model/ResourceSetBindings.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.ResourceSetBindingResponseLinks;
import com.okta.sdk.resource.model.ResourceSetBindingRole;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * ResourceSetBindings
 */
@JsonPropertyOrder({ ResourceSetBindings.JSON_PROPERTY_ROLES, ResourceSetBindings.JSON_PROPERTY_LINKS })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class ResourceSetBindings implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_ROLES = "roles";
    private List<ResourceSetBindingRole> roles = null;

    public static final String JSON_PROPERTY_LINKS = "_links";
    private ResourceSetBindingResponseLinks links;

    public ResourceSetBindings() {
    }

    public ResourceSetBindings roles(List<ResourceSetBindingRole> roles) {

        this.roles = roles;
        return this;
    }

    public ResourceSetBindings addrolesItem(ResourceSetBindingRole rolesItem) {
        if (this.roles == null) {
            this.roles = new ArrayList<>();
        }
        this.roles.add(rolesItem);
        return this;
    }

    /**
     * Get roles
     *
     * @return roles
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ROLES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<ResourceSetBindingRole> getRoles() {
        return roles;
    }

    @JsonProperty(JSON_PROPERTY_ROLES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setRoles(List<ResourceSetBindingRole> roles) {
        this.roles = roles;
    }

    public ResourceSetBindings links(ResourceSetBindingResponseLinks links) {

        this.links = links;
        return this;
    }

    /**
     * Get links
     *
     * @return links
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_LINKS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public ResourceSetBindingResponseLinks getLinks() {
        return links;
    }

    @JsonProperty(JSON_PROPERTY_LINKS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setLinks(ResourceSetBindingResponseLinks links) {
        this.links = links;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        ResourceSetBindings resourceSetBindings = (ResourceSetBindings) o;
        return Objects.equals(this.roles, resourceSetBindings.roles)
                && Objects.equals(this.links, resourceSetBindings.links);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(roles, links);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class ResourceSetBindings {\n");
        sb.append("    roles: ").append(toIndentedString(roles)).append("\n");
        sb.append("    links: ").append(toIndentedString(links)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-24.0.0-sources.jar: com/okta/sdk/resource/model/ResourceSetBindings.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.ResourceSetBindingResponseLinks;
import com.okta.sdk.resource.model.ResourceSetBindingRole;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * ResourceSetBindings
 */
@JsonPropertyOrder({ ResourceSetBindings.JSON_PROPERTY_ROLES, ResourceSetBindings.JSON_PROPERTY_LINKS })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-07-28T10:14:57.946459+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class ResourceSetBindings implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_ROLES = "roles";
    private List<ResourceSetBindingRole> roles = null;

    public static final String JSON_PROPERTY_LINKS = "_links";
    private ResourceSetBindingResponseLinks links;

    public ResourceSetBindings() {
    }

    public ResourceSetBindings roles(List<ResourceSetBindingRole> roles) {

        this.roles = roles;
        return this;
    }

    public ResourceSetBindings addrolesItem(ResourceSetBindingRole rolesItem) {
        if (this.roles == null) {
            this.roles = new ArrayList<>();
        }
        this.roles.add(rolesItem);
        return this;
    }

    /**
     * Get roles
     *
     * @return roles
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ROLES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<ResourceSetBindingRole> getRoles() {
        return roles;
    }

    @JsonProperty(JSON_PROPERTY_ROLES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setRoles(List<ResourceSetBindingRole> roles) {
        this.roles = roles;
    }

    public ResourceSetBindings links(ResourceSetBindingResponseLinks links) {

        this.links = links;
        return this;
    }

    /**
     * Get links
     *
     * @return links
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_LINKS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public ResourceSetBindingResponseLinks getLinks() {
        return links;
    }

    @JsonProperty(JSON_PROPERTY_LINKS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setLinks(ResourceSetBindingResponseLinks links) {
        this.links = links;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        ResourceSetBindings resourceSetBindings = (ResourceSetBindings) o;
        return Objects.equals(this.roles, resourceSetBindings.roles)
                && Objects.equals(this.links, resourceSetBindings.links);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(roles, links);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class ResourceSetBindings {\n");
        sb.append("    roles: ").append(toIndentedString(roles)).append("\n");
        sb.append("    links: ").append(toIndentedString(links)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
